@@ -96,7 +96,7 @@ struct nethost {
   int avg;	/* average:  addByMin */
   int gmean;	/* geometirc mean: addByMin */
   int jitter;	/* current jitter, defined as t1-t0 addByMin */
-//int jbest;	/* min jitter, of cause it is 0, not needed */
+/*int jbest;*/	/* min jitter, of cause it is 0, not needed */
   int javg;	/* avg jitter */
   int jworst;	/* max jitter */
   int jinta;	/* estimated variance,? rfc1889's "Interarrival Jitter" */
@@ -170,7 +170,8 @@ static int numhosts = 10;
 
 extern int fstTTL;		/* initial hub(ttl) to ping byMin */
 extern int maxTTL;		/* last hub to ping byMin*/
-extern int packetsize;		/* packet size used by ping */
+extern int cpacketsize;		/* packet size used by ping */
+static int packetsize;		/* packet size used by ping */
 extern int bitpattern;		/* packet bit pattern used by ping */
 extern int tos;			/* type of service set in ping packet*/
 extern int af;			/* address family of remote target */
@@ -358,7 +359,7 @@ void net_process_ping(int seq, void * addr, struct timeval now)
 
   if ( addrcmp( (void *) &(host[index].addr),
 		(void *) &unspec_addr, af ) == 0 ) {
-    // should be out of if as addr can change
+    /* should be out of if as addr can change */
     addrcpy( (void *) &(host[index].addr), addrcopy, af );
     display_rawhost(index, (void *) &(host[index].addr));
 
@@ -626,8 +627,8 @@ int net_max(void)
   int max;
 
   max = 0;
-  // replacedByMin
-  // for(at = 0; at < MaxHost-2; at++) {
+  /* replacedByMin
+     for(at = 0; at < MaxHost-2; at++) { */
   for(at = 0; at < maxTTL-1; at++) {
     if ( addrcmp( (void *) &(host[at].addr),
                   (void *) remoteaddress, af ) == 0 ) {
@@ -697,15 +698,27 @@ int net_send_batch(void)
      bitpattern<0.  abs(packetsize) and/or abs(bitpattern) will be used 
   */
   if( batch_at < fstTTL ) {
-    if( packetsize < 0 ) {
-      packetsize = 
-	- (int)(MINPACKET + (MAXPACKET-MINPACKET)*(rand()/(RAND_MAX+0.1)));
+    if( cpacketsize < 0 ) {
+	/* Someone used a formula here that tried to correct for the 
+           "end-error" in "rand()". By "end-error" I mean that if you 
+           have a range for "rand()" that runs to 32768, and the 
+           destination range is 10000, you end up with 4 out of 32768 
+           0-2768's and only 3 out of 32768 for results 2769 .. 9999. 
+           As our detination range (in the example 10000) is much 
+           smaller (reasonable packet sizes), and our rand() range much 
+           larger, this effect is insignificant. Oh! That other formula
+           didn't work. -- REW */
+      packetsize = MINPACKET + rand () % (-cpacketsize - MINPACKET);
+    } else {
+      packetsize = cpacketsize;
     }
     if( bitpattern < 0 ) {
       bitpattern = - (int)(256 + 255*(rand()/(RAND_MAX+0.1)));
     }
   }
 
+  /* printf ("cpacketsize = %d, packetsize = %d\n", cpacketsize, packetsize);  */
+
   net_send_query(batch_at);
 
   for (i=fstTTL-1;i<batch_at;i++) {
@@ -723,12 +736,12 @@ int net_send_batch(void)
       n_unknown = MaxHost; /* Make sure we drop into "we should restart" */
   }
 
-  if (	// success in reaching target
+  if (	/* success in reaching target */
      ( addrcmp( (void *) &(host[batch_at].addr),
                 (void *) remoteaddress, af ) == 0 ) ||
-      // fail in consecuitive MAX_UNKNOWN_HOSTS (firewall?)
+      /* fail in consecuitive MAX_UNKNOWN_HOSTS (firewall?) */
       (n_unknown > MAX_UNKNOWN_HOSTS) ||
-      // or reach limit 
+      /* or reach limit  */
       (batch_at >= maxTTL-1)) {
     numhosts = batch_at+1;
     batch_at = fstTTL - 1;
